@@ -6,6 +6,7 @@ from typing import cast
 from unittest.mock import AsyncMock, MagicMock, PropertyMock, patch
 
 from aiohttp import web
+from freezegun import freeze_time
 import pytest
 
 from .common import MockClient
@@ -14,6 +15,13 @@ from .utils.aiohttp import mock_aiohttp_client
 logging.basicConfig(level=logging.DEBUG)
 
 
+@pytest.fixture(autouse=True)
+def freeze_time_fixture():
+    """Freeze time for all tests by default."""
+    with freeze_time("2018-09-17 12:00:00", tick=True):
+        yield
+
+
 @pytest.fixture(name="loop")
 async def loop_fixture():
     """Return the event loop."""
@@ -64,6 +72,7 @@ def auth_cloud_mock(cloud_mock):
     """Return an authenticated cloud instance."""
     cloud_mock.auth.async_check_token.side_effect = AsyncMock()
     cloud_mock.subscription_expired = False
+    cloud_mock.instance = MagicMock(resolve_dns_cname=AsyncMock())
     return cloud_mock
 
 
